abctools.Parser
===============

.. inheritance-diagram:: abjad.tools.abctools.Parser.Parser.Parser
   :private-bases:

.. autoclass:: abjad.tools.abctools.Parser.Parser.Parser

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.debug

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.lexer

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.lexer_rules_object

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.logger

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.logger_path

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.output_path

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.parser

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.parser_rules_object

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.pickle_path

.. autoattribute:: abjad.tools.abctools.Parser.Parser.Parser.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.tokenize

Special Methods
---------------

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__call__

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abctools.Parser.Parser.Parser.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
